@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "6-Jan-24"
+#define SND_DATE "10-Feb-24"
 #ifndef SND_VERSION
-#define SND_VERSION "25.0"
+#define SND_VERSION "25.1"
 #endif
 #define SND_MAJOR_VERSION "25"
-#define SND_MINOR_VERSION "0"
+#define SND_MINOR_VERSION "1"
 
 #endif
