@@ -1048,7 +1048,7 @@
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
 <title>Snd Index</title>
-<style type=\"text/css\">
+<style>
 	EM.red {color:red; font-style:normal}
         EM.typing {color:maroon; font-style: normal}
         EM.listener {color:darkblue; font-style: normal}
@@ -1223,7 +1223,8 @@
 ;;; --------------------------------------------------------------------------------
 ;;; html-check
 
-;;; (html-check '("sndlib.html" "snd.html" "sndclm.html" "extsnd.html" "grfsnd.html" "sndscm.html" "fm.html" "balance.html" "snd-contents.html" "s7.html"))
+;;; (html-check '("sndlib.html" "snd.html" "sndclm.html" "extsnd.html" "grfsnd.html" "sndscm.html" "fm.html" "balance.html" "snd-contents.html" 
+;;;               "s7.html" "s7-ffi.html" "s7-scm.html"))
 
 (define (html-check files)
   (let ((name 0)
@@ -1592,10 +1593,10 @@
 (load-files)
 (indexit)
 
-(make-index-1 '("snd.html" "extsnd.html" "grfsnd.html" "sndscm.html" "sndlib.html" "sndclm.html" "fm.html" "s7.html")
+(make-index-1 '("snd.html" "extsnd.html" "grfsnd.html" "sndscm.html" "sndlib.html" "sndclm.html" "fm.html" "s7.html" "s7-ffi.html" "s7-scm.html")
 	      "test.html" 5 '("AIFF" "NeXT" "Sun" "RIFF" "IRCAM" "FIR" "IIR" "Hilbert" "AIFC") #t #t)
 
-(html-check '("sndlib.html" "snd.html" "extsnd.html" "grfsnd.html" "sndclm.html" "sndscm.html" "fm.html" "s7.html" "index.html"))
+(html-check '("sndlib.html" "snd.html" "extsnd.html" "grfsnd.html" "sndclm.html" "sndscm.html" "fm.html" "s7.html" "s7-ffi.html" "s7-scm.html" "index.html"))
 
 (when (> (*s7* 'profile) 0)
   (show-profile 200))
