@@ -439,6 +439,17 @@
       ((= i 10000))
     (fdot #f #t #t #f #f #t #f #f)))
 
+;;; --------------------------------------------------------------------------------
+;;; also Guile-related apparently
+
+(define-constant (mag x y)
+  (sqrt (+ (* x x) (* y y))))
+
+(let lp ((i 0))
+  (when (< i 500000)
+    (mag 3.0 4.0)
+    (lp (+ i 1))))
+
 ;;; --------------------------------------------------------------------------------
 (define (tests)
   (do ((i 0 (+ i 1)))
